==> ZenTaoPMS.17.4.php8.0.zip: zentaopms/extension/max/assetlib/lang/zh-cn.php <==
<?php
$lang->assetlib->storyLib       = '需求库';
$lang->assetlib->caseLib        = '用例库';
$lang->assetlib->issueLib       = '问题库';
$lang->assetlib->riskLib        = '风险库';
$lang->assetlib->opportunityLib = '机会库';
$lang->assetlib->practiceLib    = '最佳实践库';
$lang->assetlib->componentLib   = '组件库';
$lang->assetlib->browse         = '浏览列表';
$lang->assetlib->all            = '所有';
$lang->assetlib->story          = '需求列表';
$lang->assetlib->issue          = '问题列表';
$lang->assetlib->risk           = '风险列表';
$lang->assetlib->opportunity    = '机会列表';
$lang->assetlib->practice       = '实践列表';
$lang->assetlib->component      = '组件列表';
$lang->assetlib->libView        = '查看库概况';
$lang->assetlib->deleted        = '已删除';

$lang->assetlib->allStoryLib       = '所有需求库';
$lang->assetlib->allCaseLib        = '所有用例库';
$lang->assetlib->allIssueLib       = '所有问题库';
$lang->assetlib->allRiskLib        = '所有风险库';
$lang->assetlib->allOpportunityLib = '所有机会库';
$lang->assetlib->allPracticeLib    = '所有最佳实践库';
$lang->assetlib->allComponentLib   = '所有组件库';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = '名称';
$lang->assetlib->desc              = '描述';
$lang->assetlib->pri               = '优先级';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = '状态';
$lang->assetlib->estimate          = '预计';
$lang->assetlib->createdBy         = '创建人';
$lang->assetlib->createdDate       = '创建日期';
$lang->assetlib->approved          = '审批';
$lang->assetlib->approvedDate      = '审批日期';
$lang->assetlib->assignedTo        = '指派给';
$lang->assetlib->noAssigned        = '未指派';
$lang->assetlib->assignedDate      = '指派日期';
$lang->assetlib->approvedDate      = '审批日期';
$lang->assetlib->approveResult     = '审批结果';
$lang->assetlib->project           = '所属项目';
$lang->assetlib->plan              = '所属计划';
$lang->assetlib->allProject        = '全部项目';
$lang->assetlib->importedBy        = '由谁导入';
$lang->assetlib->importedDate      = '导入日期';
$lang->assetlib->approvedBy        = '由谁审批';
$lang->assetlib->sourceStory       = '来源需求';
$lang->assetlib->sourceIssue       = '来源问题';
$lang->assetlib->sourceRisk        = '来源风险';
$lang->assetlib->sourceOpportunity = '来源机会';
$lang->assetlib->sourceDoc         = '来源文档';
$lang->assetlib->lastEditedDate    = '最后修改日期';

/* Actions */
$lang->assetlib->createStoryLib           = '创建需求库';
$lang->assetlib->createIssueLib           = '创建问题库';
$lang->assetlib->createRiskLib            = '创建风险库';
$lang->assetlib->createOpportunityLib     = '创建机会库';
$lang->assetlib->createPracticeLib        = '创建最佳实践库';
$lang->assetlib->createComponentLib       = '创建组件库';
$lang->assetlib->edit                     = '编辑';
$lang->assetlib->editStoryLib             = '编辑需求库';
$lang->assetlib->editIssueLib             = '编辑问题库';
$lang->assetlib->editRiskLib              = '编辑风险库';
$lang->assetlib->editOpportunityLib       = '编辑机会库';
$lang->assetlib->editPracticeLib          = '编辑最佳实践库';
$lang->assetlib->editComponentLib         = '编辑组件库';
$lang->assetlib->deleteStoryLib           = '删除需求库';
$lang->assetlib->deleteIssueLib           = '删除问题库';
$lang->assetlib->deleteRiskLib            = '删除风险库';
$lang->assetlib->deleteOpportunityLib     = '删除机会库';
$lang->assetlib->deletePracticeLib        = '删除最佳实践库';
$lang->assetlib->deleteComponentLib       = '删除组件库';
$lang->assetlib->assignToStory            = '指派需求';
$lang->assetlib->assignToIssue            = '指派问题';
$lang->assetlib->assignToRisk             = '指派风险';
$lang->assetlib->assignToOpportunity      = '指派机会';
$lang->assetlib->assignToPractice         = '指派实践';
$lang->assetlib->assignToComponent        = '指派组件';
$lang->assetlib->batchAssignToStory       = '批量指派需求';
$lang->assetlib->batchAssignToIssue       = '批量指派问题';
$lang->assetlib->batchAssignToRisk        = '批量指派风险';
$lang->assetlib->batchAssignToOpportunity = '批量指派机会';
$lang->assetlib->batchAssignToPractice    = '批量指派实践';
$lang->assetlib->batchAssignToComponent   = '批量指派组件';
$lang->assetlib->approve                  = '审批';
$lang->assetlib->approveStory             = '审批需求';
$lang->assetlib->approveIssue             = '审批问题';
$lang->assetlib->approveRisk              = '审批风险';
$lang->assetlib->approveOpportunity       = '审批机会';
$lang->assetlib->approvePractice          = '审批实践';
$lang->assetlib->approveComponent         = '审批组件';
$lang->assetlib->batchApproveStory        = '批量审批需求';
$lang->assetlib->batchApproveIssue        = '批量审批问题';
$lang->assetlib->batchApproveRisk         = '批量审批风险';
$lang->assetlib->batchApproveOpportunity  = '批量审批机会';
$lang->assetlib->batchApprovePractice     = '批量审批实践';
$lang->assetlib->batchApproveComponent    = '批量审批组件';
$lang->assetlib->editStory                = '编辑需求';
$lang->assetlib->editIssue                = '编辑问题';
$lang->assetlib->editRisk                 = '编辑风险';
$lang->assetlib->editOpportunity          = '编辑机会';
$lang->assetlib->editPractice             = '编辑实践';
$lang->assetlib->editComponent            = '编辑组件';
$lang->assetlib->removeStory              = '移除需求';
$lang->assetlib->removeIssue              = '移除问题';
$lang->assetlib->removeRisk               = '移除风险';
$lang->assetlib->removeOpportunity        = '移除机会';
$lang->assetlib->removePractice           = '移除实践';
$lang->assetlib->removeComponent          = '移除组件';
$lang->assetlib->batchRemoveStory         = '批量移除需求';
$lang->assetlib->batchRemoveIssue         = '批量移除问题';
$lang->assetlib->batchRemoveRisk          = '批量移除风险';
$lang->assetlib->batchRemoveOpportunity   = '批量移除机会';
$lang->assetlib->batchRemovePractice      = '批量移除实践';
$lang->assetlib->batchRemoveComponent     = '批量移除组件';
$lang->assetlib->remove                   = '移除';

$lang->assetlib->view               = '查看库详情';
$lang->assetlib->storyLibView       = '需求库详情';
$lang->assetlib->issueLibView       = '问题库详情';
$lang->assetlib->riskLibView        = '风险库详情';
$lang->assetlib->opportunityLibView = '机会库详情';
$lang->assetlib->practiceLibView    = '最佳实践库详情';
$lang->assetlib->componentLibView   = '组件库详情';
$lang->assetlib->storyView          = '需求详情';
$lang->assetlib->issueView          = '问题详情';
$lang->assetlib->riskView           = '风险详情';
$lang->assetlib->opportunityView    = '机会详情';
$lang->assetlib->practiceView       = '最佳实践详情';
$lang->assetlib->componentView      = '组件详情';

$lang->assetlib->import            = '导入';
$lang->assetlib->importFromProject = '从项目中导入';
$lang->assetlib->importStory       = '导入需求';
$lang->assetlib->importIssue       = '导入问题';
$lang->assetlib->importRisk        = '导入风险';
$lang->assetlib->importOpportunity = '导入机会';
$lang->assetlib->importPractice    = '导入最佳实践文档';
$lang->assetlib->importComponent   = '导入组件文档';

$lang->assetlib->selectProject = '请选择项目';
$lang->assetlib->selectProduct = '请选择产品';
$lang->assetlib->selectDocLib  = '请选择文档库';
$lang->assetlib->noProject     = '现在还没有项目，请先创建！';

$lang->assetlib->storyLibDelete       = '您确认要删除该需求库吗？';
$lang->assetlib->issueLibDelete       = '您确认要删除该问题库吗？';
$lang->assetlib->riskLibDelete        = '您确认要删除该风险库吗？';
$lang->assetlib->opportunityLibDelete = '您确认要删除该机会库吗？';
$lang->assetlib->practiceLibDelete    = '您确认要删除该最佳实践库吗？';
$lang->assetlib->componentLibDelete   = '您确认要删除该组件库吗？';

$lang->assetlib->confirmDeleteStory       = '您确认要移除该需求吗？';
$lang->assetlib->confirmDeleteIssue       = '您确认要移除该问题吗？';
$lang->assetlib->confirmDeleteRisk        = '您确认要移除该风险吗？';
$lang->assetlib->confirmDeleteOpportunity = '您确认要移除该机会吗？';
$lang->assetlib->confirmDeletePractice    = '您确认要移除该最佳实践文档吗？';
$lang->assetlib->confirmDeleteComponent   = '您确认要移除该组件文档吗？';

$lang->assetlib->lib       = '所属库';
$lang->assetlib->selectLib = '请选择库';
$lang->assetlib->noLibrary = '现在还没有公共库，请先创建！';

$lang->assetlib->featureBar['all']   = '所有';
$lang->assetlib->featureBar['draft'] = '待审批';

$lang->assetlib->statusList['active'] = '已入库';
$lang->assetlib->statusList['draft']  = '待审批';

$lang->assetlib->resultList['pass']   = '通过';
$lang->assetlib->resultList['reject'] = '拒绝';

$lang->assetlib->byQuery = '搜索';

==> ZenTaoPMS.17.5.php7.2_7.4.zip: zentaopms/extension/max/assetlib/lang/zh-cn.php <==
<?php
$lang->assetlib->storyLib       = '需求库';
$lang->assetlib->caseLib        = '用例库';
$lang->assetlib->issueLib       = '问题库';
$lang->assetlib->riskLib        = '风险库';
$lang->assetlib->opportunityLib = '机会库';
$lang->assetlib->practiceLib    = '最佳实践库';
$lang->assetlib->componentLib   = '组件库';
$lang->assetlib->browse         = '浏览列表';
$lang->assetlib->all            = '所有';
$lang->assetlib->story          = '需求列表';
$lang->assetlib->issue          = '问题列表';
$lang->assetlib->risk           = '风险列表';
$lang->assetlib->opportunity    = '机会列表';
$lang->assetlib->practice       = '实践列表';
$lang->assetlib->component      = '组件列表';
$lang->assetlib->libView        = '查看库概况';
$lang->assetlib->deleted        = '已删除';

$lang->assetlib->allStoryLib       = '所有需求库';
$lang->assetlib->allCaseLib        = '所有用例库';
$lang->assetlib->allIssueLib       = '所有问题库';
$lang->assetlib->allRiskLib        = '所有风险库';
$lang->assetlib->allOpportunityLib = '所有机会库';
$lang->assetlib->allPracticeLib    = '所有最佳实践库';
$lang->assetlib->allComponentLib   = '所有组件库';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = '名称';
$lang->assetlib->desc              = '描述';
$lang->assetlib->pri               = '优先级';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = '状态';
$lang->assetlib->estimate          = '预计';
$lang->assetlib->createdBy         = '创建人';
$lang->assetlib->createdDate       = '创建日期';
$lang->assetlib->approved          = '审批';
$lang->assetlib->approvedDate      = '审批日期';
$lang->assetlib->assignedTo        = '指派给';
$lang->assetlib->noAssigned        = '未指派';
$lang->assetlib->assignedDate      = '指派日期';
$lang->assetlib->approvedDate      = '审批日期';
$lang->assetlib->approveResult     = '审批结果';
$lang->assetlib->project           = '所属项目';
$lang->assetlib->plan              = '所属计划';
$lang->assetlib->allProject        = '全部项目';
$lang->assetlib->importedBy        = '由谁导入';
$lang->assetlib->importedDate      = '导入日期';
$lang->assetlib->approvedBy        = '由谁审批';
$lang->assetlib->sourceStory       = '来源需求';
$lang->assetlib->sourceIssue       = '来源问题';
$lang->assetlib->sourceRisk        = '来源风险';
$lang->assetlib->sourceOpportunity = '来源机会';
$lang->assetlib->sourceDoc         = '来源文档';
$lang->assetlib->lastEditedDate    = '最后修改日期';

/* Actions */
$lang->assetlib->createStoryLib           = '创建需求库';
$lang->assetlib->createIssueLib           = '创建问题库';
$lang->assetlib->createRiskLib            = '创建风险库';
$lang->assetlib->createOpportunityLib     = '创建机会库';
$lang->assetlib->createPracticeLib        = '创建最佳实践库';
$lang->assetlib->createComponentLib       = '创建组件库';
$lang->assetlib->edit                     = '编辑';
$lang->assetlib->editStoryLib             = '编辑需求库';
$lang->assetlib->editIssueLib             = '编辑问题库';
$lang->assetlib->editRiskLib              = '编辑风险库';
$lang->assetlib->editOpportunityLib       = '编辑机会库';
$lang->assetlib->editPracticeLib          = '编辑最佳实践库';
$lang->assetlib->editComponentLib         = '编辑组件库';
$lang->assetlib->deleteStoryLib           = '删除需求库';
$lang->assetlib->deleteIssueLib           = '删除问题库';
$lang->assetlib->deleteRiskLib            = '删除风险库';
$lang->assetlib->deleteOpportunityLib     = '删除机会库';
$lang->assetlib->deletePracticeLib        = '删除最佳实践库';
$lang->assetlib->deleteComponentLib       = '删除组件库';
$lang->assetlib->assignToStory            = '指派需求';
$lang->assetlib->assignToIssue            = '指派问题';
$lang->assetlib->assignToRisk             = '指派风险';
$lang->assetlib->assignToOpportunity      = '指派机会';
$lang->assetlib->assignToPractice         = '指派实践';
$lang->assetlib->assignToComponent        = '指派组件';
$lang->assetlib->batchAssignToStory       = '批量指派需求';
$lang->assetlib->batchAssignToIssue       = '批量指派问题';
$lang->assetlib->batchAssignToRisk        = '批量指派风险';
$lang->assetlib->batchAssignToOpportunity = '批量指派机会';
$lang->assetlib->batchAssignToPractice    = '批量指派实践';
$lang->assetlib->batchAssignToComponent   = '批量指派组件';
$lang->assetlib->approve                  = '审批';
$lang->assetlib->approveStory             = '审批需求';
$lang->assetlib->approveIssue             = '审批问题';
$lang->assetlib->approveRisk              = '审批风险';
$lang->assetlib->approveOpportunity       = '审批机会';
$lang->assetlib->approvePractice          = '审批实践';
$lang->assetlib->approveComponent         = '审批组件';
$lang->assetlib->batchApproveStory        = '批量审批需求';
$lang->assetlib->batchApproveIssue        = '批量审批问题';
$lang->assetlib->batchApproveRisk         = '批量审批风险';
$lang->assetlib->batchApproveOpportunity  = '批量审批机会';
$lang->assetlib->batchApprovePractice     = '批量审批实践';
$lang->assetlib->batchApproveComponent    = '批量审批组件';
$lang->assetlib->editStory                = '编辑需求';
$lang->assetlib->editIssue                = '编辑问题';
$lang->assetlib->editRisk                 = '编辑风险';
$lang->assetlib->editOpportunity          = '编辑机会';
$lang->assetlib->editPractice             = '编辑实践';
$lang->assetlib->editComponent            = '编辑组件';
$lang->assetlib->removeStory              = '移除需求';
$lang->assetlib->removeIssue              = '移除问题';
$lang->assetlib->removeRisk               = '移除风险';
$lang->assetlib->removeOpportunity        = '移除机会';
$lang->assetlib->removePractice           = '移除实践';
$lang->assetlib->removeComponent          = '移除组件';
$lang->assetlib->batchRemoveStory         = '批量移除需求';
$lang->assetlib->batchRemoveIssue         = '批量移除问题';
$lang->assetlib->batchRemoveRisk          = '批量移除风险';
$lang->assetlib->batchRemoveOpportunity   = '批量移除机会';
$lang->assetlib->batchRemovePractice      = '批量移除实践';
$lang->assetlib->batchRemoveComponent     = '批量移除组件';
$lang->assetlib->remove                   = '移除';

$lang->assetlib->view               = '查看库详情';
$lang->assetlib->storyLibView       = '需求库详情';
$lang->assetlib->issueLibView       = '问题库详情';
$lang->assetlib->riskLibView        = '风险库详情';
$lang->assetlib->opportunityLibView = '机会库详情';
$lang->assetlib->practiceLibView    = '最佳实践库详情';
$lang->assetlib->componentLibView   = '组件库详情';
$lang->assetlib->storyView          = '需求详情';
$lang->assetlib->issueView          = '问题详情';
$lang->assetlib->riskView           = '风险详情';
$lang->assetlib->opportunityView    = '机会详情';
$lang->assetlib->practiceView       = '最佳实践详情';
$lang->assetlib->componentView      = '组件详情';

$lang->assetlib->import            = '导入';
$lang->assetlib->importFromProject = '从项目中导入';
$lang->assetlib->importStory       = '导入需求';
$lang->assetlib->importIssue       = '导入问题';
$lang->assetlib->importRisk        = '导入风险';
$lang->assetlib->importOpportunity = '导入机会';
$lang->assetlib->importPractice    = '导入最佳实践文档';
$lang->assetlib->importComponent   = '导入组件文档';

$lang->assetlib->selectProject = '请选择项目';
$lang->assetlib->selectProduct = '请选择产品';
$lang->assetlib->selectDocLib  = '请选择文档库';
$lang->assetlib->noProject     = '现在还没有项目，请先创建！';

$lang->assetlib->storyLibDelete       = '您确认要删除该需求库吗？';
$lang->assetlib->issueLibDelete       = '您确认要删除该问题库吗？';
$lang->assetlib->riskLibDelete        = '您确认要删除该风险库吗？';
$lang->assetlib->opportunityLibDelete = '您确认要删除该机会库吗？';
$lang->assetlib->practiceLibDelete    = '您确认要删除该最佳实践库吗？';
$lang->assetlib->componentLibDelete   = '您确认要删除该组件库吗？';

$lang->assetlib->confirmDeleteStory       = '您确认要移除该需求吗？';
$lang->assetlib->confirmDeleteIssue       = '您确认要移除该问题吗？';
$lang->assetlib->confirmDeleteRisk        = '您确认要移除该风险吗？';
$lang->assetlib->confirmDeleteOpportunity = '您确认要移除该机会吗？';
$lang->assetlib->confirmDeletePractice    = '您确认要移除该最佳实践文档吗？';
$lang->assetlib->confirmDeleteComponent   = '您确认要移除该组件文档吗？';

$lang->assetlib->lib       = '所属库';
$lang->assetlib->selectLib = '请选择库';
$lang->assetlib->noLibrary = '现在还没有公共库，请先创建！';

$lang->assetlib->featureBar['browse']['all']   = '所有';
$lang->assetlib->featureBar['browse']['draft'] = '待审批';

$lang->assetlib->featureBar['caselib']['all'] = $lang->assetlib->all;

$lang->assetlib->statusList['active'] = '已入库';
$lang->assetlib->statusList['draft']  = '待审批';

$lang->assetlib->resultList['pass']   = '通过';
$lang->assetlib->resultList['reject'] = '拒绝';

$lang->assetlib->byQuery = '搜索';
